@@ -14,7 +14,6 @@
 #    under the License.
 
 import datetime
-import json
 import logging
 import re
 
@@ -157,7 +156,7 @@ class CreateForm(forms.SelfHandlingForm):
             'class': 'switched',
             'data-switch-on': 'source',
             'data-source-instance': _('Affinity Rule')})
-        )
+    )
 
     # Fields for both of host and instance reservations
     resource_properties = forms.CharField(
@@ -176,8 +175,8 @@ class CreateForm(forms.SelfHandlingForm):
                     'resource_type': 'physical:host',
                     'min': data['min_hosts'],
                     'max': data['max_hosts'],
-                    'hypervisor_properties': (data['hypervisor_properties']
-                                              or ''),
+                    'hypervisor_properties': (data['hypervisor_properties'] or
+                                              ''),
                     'resource_properties': data['resource_properties'] or ''
                 }
             ]
@@ -228,8 +227,8 @@ class CreateForm(forms.SelfHandlingForm):
                 cleaned_data['end_date'].replace(tzinfo=None)
             ).astimezone(timezone('UTC'))
         else:
-            cleaned_data['end_date'] = (cleaned_data['start_date']
-                                        + datetime.timedelta(days=1))
+            cleaned_data['end_date'] = (cleaned_data['start_date'] +
+                                        datetime.timedelta(days=1))
 
 
 class UpdateForm(forms.SelfHandlingForm):
@@ -325,14 +324,14 @@ class UpdateForm(forms.SelfHandlingForm):
         reservations = cleaned_data.get("reservations", None)
 
         if start_time:
-            valid = re.match('^[+-]\d+[dhm]$', start_time)
+            valid = re.match(r'^[+-]\d+[dhm]$', start_time)
             if not valid:
                 raise forms.ValidationError("The start/end time must be "
                                             "a form of +/- number d/h/m. "
                                             "(e.g. +1h)")
 
         if end_time:
-            valid = re.match('^[+-]\d+[dhm]$', end_time)
+            valid = re.match(r'^[+-]\d+[dhm]$', end_time)
             if not valid:
                 raise forms.ValidationError("The start/end time must be "
                                             "a form of +/- number d/h/m. "
@@ -340,11 +339,11 @@ class UpdateForm(forms.SelfHandlingForm):
 
         if reservations:
             try:
-                reservations = json.loads(reservations)
+                reservations = eval(reservations)
                 cleaned_data['reservations'] = reservations
-            except json.JSONDecodeError:
+            except (SyntaxError, NameError):
                 raise forms.ValidationError(
-                    _('Reservation values must be written in JSON')
+                    _('Reservation values must written in JSON')
                 )
 
         if not (lease_name or start_time or end_time or reservations):
