@@ -142,7 +142,7 @@ host_sample1 = {
     "updated_at": None,
     "hypervisor_hostname": "compute-1",
     "memory_mb": 4096,
-    "cpu_info": "{\"dummy\": \"true\"}",
+    "cpu_info": "{'dummy': 'true'}",
     "vcpus": 1,
     "service_name": "blazar",
     "hypervisor_version": 2005000,
@@ -160,7 +160,7 @@ host_sample2 = {
     "updated_at": None,
     "hypervisor_hostname": "compute-2",
     "memory_mb": 4096,
-    "cpu_info": "{\"dummy\": \"true\"}",
+    "cpu_info": "{'dummy': 'true'}",
     "vcpus": 1,
     "service_name": "blazar",
     "hypervisor_version": 2005000,
@@ -176,6 +176,7 @@ class DummyHypervisor(object):
     def __init__(self, host_name):
         self.hypervisor_hostname = host_name
 
+
 hypervisor_sample1 = DummyHypervisor('compute-1')
 hypervisor_sample2 = DummyHypervisor('compute-2')
 
